#!/bin/sh -e

CON_NAME="$1"
SSID="$2"
SECURITY="$3"
PASSWORD="$4"
INTERFACE="$5"
METHOD="$6"

CON_FILE="/etc/NetworkManager/system-connections/$CON_NAME.nmconnection"

trap catch ERR

while [[ $# -gt 0 ]];
do
	case "$1" in
		"-a")
			shift
			IP_ADDR="$1" ;;
		"-g")
			shift
			GATEWAY_ADDR="$1" ;;
		"-d")
			shift
			DNS_ADDR="$1" ;;
		*)
			;;
	esac
	shift
done

catch() {
	if nmcli con show "$CON_NAME" >/dev/null 2>&1; then
		nmcli con del "$CON_NAME"
		persist_file -d "$CON_FILE" || :
	fi
	echo "Could not set up wlan connection." >&2
}

if nmcli con show "$CON_NAME" >/dev/null 2>&1; then
	set -- nmcli con mod "$CON_NAME"
else
	set -- nmcli con add con-name "$CON_NAME" type wifi ifname "$INTERFACE" \
		ssid "$SSID" wifi-sec.key-mgmt "$SECURITY" wifi-sec.psk "$PASSWORD"
fi

if [ "$METHOD" = "auto" ]; then
	set -- "$@" ipv4.method auto
else
	set -- "$@" ipv4.method manual ipv4.addresses "$IP_ADDR" ipv4.gateway "$GATEWAY_ADDR"
fi

if [ -n "$DNS_ADDR" ]; then
	set -- "$@" ipv4.dns "$DNS_ADDR"
fi

"$@"
nmcli con up "$CON_NAME"
persist_file "$CON_FILE"
